import {FC, useState} from 'react'
import * as Yup from 'yup'
import {useFormik} from 'formik'
import {isNotEmpty, QUERIES, toAbsoluteUrl} from '../../../../../../../_metronic/helpers'
import {initialPerson, initialPersonRole, initialPersonRoleType, Person, PersonRole, PersonRoleType} from '../../core/_models'
import clsx from 'clsx'
import {useListView} from './ListViewProviderPerson'
import {ListLoading} from '../../components/loading/ListLoading'
import {getPersonRoleTypes, savePerson} from '../../core/_requests'
import {useQueryResponse} from '../../core/QueryResponseProviderPerson'
import {useQuery} from 'react-query'
import { CREATE_PERSON_ROLE } from '../../../../AppUtils'
import {useQueryClient} from 'react-query'

type Props = {
  isUserLoading: boolean
  user: Person
}

const PersonRoleAddModalForm: FC<Props> = ({user, isUserLoading}) => {
  const {setItemIdForUpdate} = useListView()
  const {refetch} = useQueryResponse()
  const queryClient = useQueryClient()
  const {query} = useQueryResponse()

  const {
    isLoading,
    data: personRoleTypes,
    error,
  } = useQuery(
    `${QUERIES.PERSON_ROLE_TYPE_LIST}-personRoleType-${undefined}`,
    () => {
      return getPersonRoleTypes()
    },
    {
      cacheTime: 0,
      enabled: true,
      onError: (err) => {
        console.error(err)
      },
    }
  )
    console.log(user.personRoles)

  const [personRoleTypeForEdit] = useState<PersonRole>({
    personRoleType: initialPersonRoleType
  })

  const cancel = (withRefresh?: boolean) => {
    if (withRefresh) {
      refetch()
    }
    setItemIdForUpdate(undefined)
  }

  const blankImg = toAbsoluteUrl('/media/svg/avatars/blank.svg')
  const userAvatarImg = toAbsoluteUrl('avatars/300-6.jpg')

  const formik = useFormik({
    initialValues: personRoleTypeForEdit,
    onSubmit: async (values, {setSubmitting}) => {
      console.log(values)
      user.personRoles?.push(values)
      console.log(user)
      setSubmitting(true)
      try {
 
          await savePerson(user)
          
      } catch (ex) {
        console.error(ex)
      } finally {
        setSubmitting(true)
        cancel(true)
        queryClient.invalidateQueries([`${QUERIES.PERSONS_LIST}-${query}`])

      }
    },
  })

  return (
    <>
      <form id='kt_modal_add_user_form' className='form' onSubmit={formik.handleSubmit} noValidate>
        {/* begin::Scroll */}
        <div
          className='d-flex flex-column scroll-y me-n7 pe-7'
          id='kt_modal_add_user_scroll'
          data-kt-scroll='true'
          data-kt-scroll-activate='{default: false, lg: true}'
          data-kt-scroll-max-height='auto'
          data-kt-scroll-dependencies='#kt_modal_add_user_header'
          data-kt-scroll-wrappers='#kt_modal_add_user_scroll'
          data-kt-scroll-offset='300px'
        >
          {/* begin::Input group */}
          <div className='fv-row mb-7'>
            {/* begin::Label */}
            <label className='required fw-bold fs-6 mb-2'>Personrollstyp</label>
            {/* end::Label */}

            {/* begin::Input */}
            {personRoleTypes?.data && personRoleTypes?.data?.filter(x => !user.personRoles?.map(personRole => Number(personRole.personRoleType?.id)).find(roleId => roleId === Number(x.id))).map( personRoleType=> {
                  return(
                <div className='fv-row' key={personRoleType.id}>
                  {/* begin::Radio */}
                  <div className='form-check form-check-custom form-check-solid'>
                    {/* begin::Input */}
                    <input
                      className='form-check-input me-3'
                      {...formik.getFieldProps('personRoleType.id')}
                      name='personRoleType.id'
                      type='radio'
                      value={String(personRoleType.id)}
                      id='kt_modal_update_role_option_0'
                      //checked={formik.values.personroles === 'Administrator'}
                      disabled={formik.isSubmitting || isLoading}
                    />
                    {/* end::Input */}
                  
                    {/* begin::Label */}
                    <label className='form-check-label' htmlFor='kt_modal_update_role_option_0'>
                      <div className='fw-bolder text-gray-800'>{personRoleType.name}</div>

                    </label>
                    {/* end::Label */}
                    
                  </div>
                  {/* end::Radio */}
                  <div className='fv-row mb-7'> </div>


                </div>
                
                )
              } )}
            {/* end::Input */}
          </div>
          {/* end::Input group */}
        </div>
        {/* end::Scroll */}

        {/* begin::Actions */}
        <div className='text-center pt-15'>
          <button
            type='reset'
            onClick={() => cancel()}
            className='btn btn-light me-3'
            data-kt-users-modal-action='cancel'
            disabled={formik.isSubmitting || isUserLoading}
          >
            Discard
          </button>

          <button
            type='submit'
            className='btn btn-primary'
            data-kt-users-modal-action='submit'
            disabled={isUserLoading || formik.isSubmitting || !formik.isValid || !formik.touched}
          >
            <span className='indicator-label'>Submit</span>
            {(formik.isSubmitting || isUserLoading) && (
              <span className='indicator-progress'>
                Please wait...{' '}
                <span className='spinner-border spinner-border-sm align-middle ms-2'></span>
              </span>
            )}
          </button>
        </div>
        {/* end::Actions */}
      </form>
      {(formik.isSubmitting || isUserLoading) && <ListLoading />}
    </>
  )
}

export {PersonRoleAddModalForm}
